Sentry
======

Sentry is a modern error logging and aggregation platform.


Sentry is a Server
------------------

The Sentry package fundamentally is just a simple server and web UI. It will
handle authenticating clients (such as `Raven <https://github.com/getsentry/raven-python>`_)
and all of the logic behind storage and aggregation.

That said, Sentry is not limited to Python. The primary implementation is in
Python, but it contains a full API for sending events from any language, in
any application.


Resources
---------

* `Documentation <https://docs.sentry.io/>`_
* `Community <https://forum.sentry.io/>`_ (Bugs, feature requests, general questions)
* `Bug Tracker <https://github.com/getsentry/sentry/issues>`_
* `Code <https://github.com/getsentry/sentry>`_
* `IRC <irc://irc.freenode.net/sentry>`_  (irc.freenode.net, #sentry)
* `Transifex <https://www.transifex.com/getsentry/sentry/>`_ (Translate Sentry!)
